import express from 'express';
import corsMiddleware from 'cors';
import { OptionsJson } from 'body-parser';
import { GraphQLOptions, ApolloServerBase, ContextFunction, Context, Config } from 'apollo-server-core';
export { GraphQLOptions, GraphQLExtension } from 'apollo-server-core';
export interface ServerRegistration {
    app: express.Application;
    path?: string;
    cors?: corsMiddleware.CorsOptions | boolean;
    bodyParserConfig?: OptionsJson | boolean;
    onHealthCheck?: (req: express.Request) => Promise<any>;
    disableHealthCheck?: boolean;
}
export interface ExpressContext {
    req: express.Request;
    res: express.Response;
}
export interface ApolloServerExpressConfig extends Config {
    context?: ContextFunction<ExpressContext, Context> | Context;
}
export declare class ApolloServer extends ApolloServerBase {
    constructor(config: ApolloServerExpressConfig);
    createGraphQLServerOptions(req: express.Request, res: express.Response): Promise<GraphQLOptions>;
    protected supportsSubscriptions(): boolean;
    protected supportsUploads(): boolean;
    applyMiddleware({ app, path, cors, bodyParserConfig, disableHealthCheck, onHealthCheck, }: ServerRegistration): void;
}
export declare const registerServer: () => never;
//# sourceMappingURL=ApolloServer.d.ts.map